@@ -2,14 +2,14 @@
 
 from .ternary_diagram import *
 
-__version__      = '1.4.0'
+__version__      = '1.5.6'
 __license__      = 'MIT'
-__author__       = 'yu-9824'
-__copyright__ = 'Copyright (c) 2021 yu-9824'
+__author__       = 'yu9824'
+__copyright__ = 'Copyright © 2021 yu9824'
 __author_email__ = 'yu.9824.job@gmail.com'
-__user_id__ = 'yu-9824'
+__user_id__ = 'yu9824'
 __app_name__ = 'ternary_diagram'
-__url__ = 'http://github.com/yu-9824/ternary_diagram/'
+__url__ = 'http://github.com/yu9824/ternary_diagram/'
 
 __all__ = [
     'TernaryDiagram',
